package com.dgtly.common.utils;

import com.dgtly.common.utils.http.HttpUtils;
import net.sf.json.JSONArray;
import net.sf.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author koucx
 * @version 1.0
 * @descption: 中文翻译英文工具类
 * @company 神州数码通用软件（洛阳）有限公司
 * @copyright (c) 2019 LuoYang DGT Co'Ltd Inc. All rights reserved.
 * @date 2020-03-24
 * @since JDK1.8
 */
public class TranslateUtil {

    private static final Logger log = LoggerFactory.getLogger(TranslateUtil.class);

    private static final String TRANSLATE_URL_OLD = "http://fanyi.youdao.com/translate";
    private static final String TRANSLATE_URL = "http://fanyi.youdao.com/openapi.do";

    private static final String regEx_script = "<script[^>]*?>[\\s\\S]*?<\\/script>"; // 定义script的正则表达式
    private static final String regEx_style = "<style[^>]*?>[\\s\\S]*?<\\/style>"; // 定义style的正则表达式
    private static final String regEx_html = "<[^>]+>"; // 定义HTML标签的正则表达式
    private static final String regEx_space = "\\s*|\t|\r|\n";//定义空格回车换行符


    /**
     * @param htmlStr
     * @return 删除Html标签
     */
    public static String delHTMLTag(String htmlStr) {
        Pattern p_script = Pattern.compile(regEx_script, Pattern.CASE_INSENSITIVE);
        Matcher m_script = p_script.matcher(htmlStr);
        htmlStr = m_script.replaceAll(""); // 过滤script标签

        Pattern p_style = Pattern.compile(regEx_style, Pattern.CASE_INSENSITIVE);
        Matcher m_style = p_style.matcher(htmlStr);
        htmlStr = m_style.replaceAll(""); // 过滤style标签

        Pattern p_html = Pattern.compile(regEx_html, Pattern.CASE_INSENSITIVE);
        Matcher m_html = p_html.matcher(htmlStr);
        List<String> matchStrs = new ArrayList<>();
        while (m_html.find()) { //此处find（）每次被调用后，会偏移到下一个匹配
            matchStrs.add(m_html.group());//获取当前匹配的值
        }

        for (int i = 0; i < matchStrs.size(); i++) {
            System.out.println(matchStrs.get(i));
        }

        htmlStr = m_html.replaceAll(""); // 过滤html标签

        Pattern p_space = Pattern.compile(regEx_space, Pattern.CASE_INSENSITIVE);
        Matcher m_space = p_space.matcher(htmlStr);
        htmlStr = m_space.replaceAll(""); // 过滤空格回车标签
        htmlStr = htmlStr.replaceAll("&nbsp;", "");
        htmlStr = htmlStr.replaceAll("↵", "");
        return htmlStr.trim(); // 返回文本字符串
    }

    /**
     * 处理含有html的翻译
     * @param html
     * @return
     */
    public static String getDesEnTranslateInfo(String html){

        Pattern p_html = Pattern.compile(regEx_html);
        String[] split = p_html.split(html);
        List<String> translates = new ArrayList();
        for (int i = 0; i <split.length ; i++) {
            String s =  split[i].replaceAll("&nbsp;","").trim();
            if(StringUtils.isNotEmpty(s)){
                translates.add(s);
            }
        }

        for (int i = 0; i <translates.size() ; i++) {
            html = html.replaceFirst(translates.get(i),getEnTranslateInfo(translates.get(i)));
        }
        return html;
    }


    /**
     * @Description: 调用有道翻译接口中文翻译成英文
     * @Param: [msg]
     * @Return: java.lang.String
     * @Author: koucx
     * @Date: 2020-03-24
    **/
    public static String getEnTranslateInfo(String msg){
        String params = "doctype=json&type=ZH_CN2EN&i="+msg;
        try{
            String enInfo = HttpUtils.sendGet(TRANSLATE_URL_OLD, params);
            /**
             * {
             *     "type": "ZH_CN2EN",
             *     "errorCode": 0,
             *     "elapsedTime": 1,
             *     "translateResult": [
             *         [
             *             {
             *                 "src": "计算",//需要翻译的中文
             *                 "tgt": "To calculate"//翻译后的中文
             *             }
             *         ]
             *     ]
             * }
             *
             * 根据以上json串获取相应英文翻译
             *
             */
            if(StringUtils.isNotEmpty(enInfo)){
                JSONObject object = JSONObject.fromObject(enInfo);
                if(object!=null){
                    JSONArray array = object.getJSONArray("translateResult");
                    if(array!=null && array.size()>0){
                        String tgt = "";
                        for (Object obj:array) {
                            JSONArray arr = JSONArray.fromObject(obj);
                            for (Object o:arr) {
                                JSONObject json = JSONObject.fromObject(o);
                                if(json!=null && json.containsKey("tgt")){
                                        tgt +=" "+json.getString("tgt");
                                }
                            }
                        }
                        return tgt;
                    }
                }
            }
        }catch (Exception e){
            log.info("翻译出错");
        }
        return "";
    }

    /**
     * @Description: 调用有道翻译接口中文翻译成英文
     * @Param: [msg]
     * @Verision:2.0
     * @Return: java.lang.String
     * @Author: koucx
     * @Date: 2020-03-24
     **/
    public static String getEnTranslateInfoOld(String msg){

        try{
            if(StringUtils.isNotEmpty(msg)){
                String params = "keyfrom=pdblog&key=993123434&type=data&doctype=json&version=1.1&q="+ URLEncoder.encode(msg,"utf-8");
                String enInfo = HttpUtils.sendGet(TRANSLATE_URL, params);
                JSONObject jsonObject = JSONObject.fromObject(enInfo);
                if(jsonObject!=null){
                    Object obj = jsonObject.get("translation");
                    JSONArray jsonArray = JSONArray.fromObject(obj);
                    if(jsonArray!=null && jsonArray.size()>0){
                        return jsonArray.get(0)==null?"":jsonArray.get(0).toString();
                    }
                }
            }
        }catch (Exception e){
            log.info("翻译出错");
        }
        return "";
    }


    public static void main(String[] args) {
        String htmlStr = "<p style=\"margin-bottom: 15px; padding: 0px; max-width: 100%; color: rgb(62, 62, 62); font-family: 微软雅黑; font-size: 12px;\"><a href=\"http://www.kefeiyajiaju.com/products/#FILECABINETS\" target=\"_self\" style=\"margin: 0px; padding: 0px; color: rgb(10, 10, 10); max-width: 100%;\"><span style=\"margin: 0px; padding: 0px; max-width: 100%; font-family: 微软雅黑, &quot;Microsoft YaHei&quot;; font-size: 16px;\">铁皮文件柜</span></a><span style=\"margin: 0px; padding: 0px; max-width: 100%; font-family: 微软雅黑, &quot;Microsoft YaHei&quot;; font-size: 16px;\">作为一种有市场，有价值，有成本的产品，会因为厂家提供直销价格或参加一些厂家活动而变得价格优惠，比市场平均价便宜许多，但绝对不会低到廉价。</span></p><p style=\"margin-bottom: 15px; padding: 0px; max-width: 100%; color: rgb(62, 62, 62); font-family: 微软雅黑; font-size: 12px;\"><span style=\"margin: 0px; padding: 0px; max-width: 100%; font-family: 微软雅黑, &quot;Microsoft YaHei&quot;; font-size: 16px;\">好的铁皮文件柜需要保证厚实的原材，这是长久使用不变形不损坏的基础。降低价钱的方法当然有，那就是降低成本，降低成本就是降低原材厚度。你买到了便宜，但是却不能用，钱还是白白丢了。看似省了一两百，其实很不划算。</span></p><p style=\"margin-bottom: 15px; padding: 0px; max-width: 100%; color: rgb(62, 62, 62); font-family: 微软雅黑; font-size: 12px;\">&nbsp; &nbsp;&nbsp;<span style=\"margin: 0px; padding: 0px; max-width: 100%; font-family: 微软雅黑, &quot;Microsoft YaHei&quot;; font-size: 16px;\">从我们这里出的每台铁皮文件柜都会精致到每个细节。不仅是外在的光滑美观平整，内部结构的稳定，人性化的空间设计还有配件的高质量。这些容易被忽略的地方，却实实在在的为柜子的结实耐用加分，使用起来更觉得方便。有些柜子看起来一样，但是却不能环保达标。环保需要从基材就把好关。&nbsp; &nbsp; &nbsp;<br></span></p><p style=\"margin-bottom: 15px; padding: 0px; max-width: 100%; color: rgb(62, 62, 62); font-family: 微软雅黑; font-size: 12px;\"><span style=\"margin: 0px; padding: 0px; max-width: 100%; font-family: 微软雅黑, &quot;Microsoft YaHei&quot;; font-size: 16px;\">所以作为消费者的我们，一定不要光看报价，更要多了解商家的制作技术和原料，假如数量大，可亲自到出产工厂去观赏，最直接的了解商家所用资料。</span></p>";
        Pattern p_html = Pattern.compile(regEx_html);
        String[] split = p_html.split(htmlStr);
        List<String> translates = new ArrayList();
        for (int i = 0; i <split.length ; i++) {
           String s =  split[i].replaceAll("&nbsp;","").trim();
            if(StringUtils.isNotEmpty(s)){
                translates.add(s);
            }
        }

        for (int i = 0; i <translates.size() ; i++) {
            htmlStr = htmlStr.replaceFirst(translates.get(i),getEnTranslateInfo(translates.get(i)));
        }
        System.out.println(htmlStr);
    }

}
