package com.dgtly.goods.mapper;

import com.dgtly.common.annotation.SwitchEn;
import com.dgtly.goods.domain.GoodsInfo;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 商品基础详情Mapper接口
 * 
 * @author dgtly
 * @date 2020-02-13
 */
public interface GoodsInfoMapper 
{
    /**
     * 查询商品基础详情
     * 
     * @param id 商品基础详情ID
     * @return 商品基础详情
     */
    @SwitchEn(oldfiles ={"gi.name","gi.des","gi.delivery","gi.produced_address","gi.warehouse_address","gi.material","ga.VALUE","gt.NAME","gs.size","gc.color","gta.attribute_name","sc.company_name","gt.name"},
              newfiles = {"gi.name_en name","gi.des_en des","gi.delivery_en delivery","gi.produced_address_en produced_address",
                      "gi.warehouse_address_en warehouse_address","gi.material_en material","ga.VALUE_EN value","gt.NAME_EN typeName","gs.size_en size","gc.color_en color","gta.attribute_name_en","sc.company_name_en","gt.name_en"})
    public GoodsInfo selectGoodsInfoById(Long id);

    /**
     * 查询商品基础详情列表
     * 
     * @param goodsInfo 商品基础详情
     * @return 商品基础详情集合
     */
    public List<GoodsInfo> selectGoodsInfoList(GoodsInfo goodsInfo);

    public List<GoodsInfo> selectGoodsInfoListByAdmin(GoodsInfo goodsInfo);
    /**
     * 新增商品基础详情
     * 
     * @param goodsInfo 商品基础详情
     * @return 结果
     */
    public int insertGoodsInfo(GoodsInfo goodsInfo);

    /**
     * 修改商品基础详情
     * 
     * @param goodsInfo 商品基础详情
     * @return 结果
     */
    public int updateGoodsInfo(GoodsInfo goodsInfo);

    /**
     * 删除商品基础详情
     * 
     * @param id 商品基础详情ID
     * @return 结果
     */
    public int deleteGoodsInfoById(Long id);

    /**
     * 批量删除商品基础详情
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteGoodsInfoByIds(String[] ids);



    /**
     * @descption: 根据分类id查询商品数量包括小雷的
     * @param:
     * @return:
     * @auther: qxp
     * @date: 2020-2-25
     */
    public int selectGoodsInfoCountByTypeId(Long typeId);

    /**
     * @descption: 为前端网页提供商品查询，价格筛选
     * @param:
     * @return:
     * @auther: qxp
     * @date: 2020/3/3 10:43
     */
    @SwitchEn(oldfiles ={"gi.name","gi.material","gt.name","sc.company_name"},
            newfiles = {"gi.name_en name","gi.material_en material","gt.name_en","sc.company_name_en"})
    public List<GoodsInfo> selectGoodsInfoListInWeb(GoodsInfo gi);

    /**
     * @descption: 批量查询商品
     * @param:
     * @return:
     * @auther: qxp
     * @date: 2020/3/3 10:43
     */
    List<GoodsInfo> selectGoodsInfoByIds(String[] ids);


    public int countGoodsInfo();
    /**
     * @descption: 批量上下架
     * @param:
     * @return:
     * @auther: qxp
     * @date: 2020/3/3 10:43
     */
    int putawayGooodsInfo(@Param("ids") String[] ids, @Param("putawayFlag")String putawayFlag);


}
