package com.dgtly.member.service;

import com.dgtly.member.domain.MemberInfo;
import java.util.List;

/**
 * 会员信息Service接口
 * 
 * @author dgtly
 * @date 2020-02-13
 */
public interface IMemberInfoService 
{
    /**
     * 查询会员信息
     * 
     * @param id 会员信息ID
     * @return 会员信息
     */
    public MemberInfo selectMemberInfoById(Long id);

    /**
     * 查询会员信息列表
     * 
     * @param memberInfo 会员信息
     * @return 会员信息集合
     */
    public List<MemberInfo> selectMemberInfoList(MemberInfo memberInfo);

    /**
     * 新增会员信息
     * 
     * @param memberInfo 会员信息
     * @return 结果
     */
    public int insertMemberInfo(MemberInfo memberInfo);

    /**
     * 修改会员信息
     * 
     * @param memberInfo 会员信息
     * @return 结果
     */
    public int updateMemberInfo(MemberInfo memberInfo);

    /**
     * 批量删除会员信息
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteMemberInfoByIds(String ids);

    /**
     * 删除会员信息信息
     * 
     * @param id 会员信息ID
     * @return 结果
     */
    public int deleteMemberInfoById(Long id);

    /**
     * @descption: 检测登录账号的唯一性
     * @param: 登录账号
     * @return: 会员实体
     * @auther: LiuLingChao
     * @date: 2020-2-25 15:12
     */
     public int checkMemberUnique(String loginAccount );
    /**
     * @descption: 检测手机号唯一性
     * @param: 手机号
     * @return: 会员实体
     * @auther: LiuLingChao
     * @date: 2020-2-25 15:12
     */
     public int checkMemberPhoneUnique(String phone );


     /**
      * @descption: 用户登录
      * @param: 登录账号/手机号、密码
      * @return:
      * @auther: LiuLingChao
      * @date: 2020-2-25 15:39
      */
    public MemberInfo memberLogin(MemberInfo info);


    /**
     * @descption: 统计平台会员注册量
     * @param:
     * @return:
     * @auther: LiuLingChao
     * @date: 2020-03-11 10:46
     */
    public int countMemberInfo();

    /**
     * @descption: 查询
     * @param:
     * @return:
     * @auther: qxp
     * @date: 2020-03-11 10:46
     */
    public MemberInfo selectMemberInfoByAccountPhone(String loginAccount, String loginPassword);
}
