package com.dgtly.companyext.mapper;

import com.dgtly.common.annotation.SwitchEn;
import com.dgtly.companyext.domain.CompanyReviewed;
import java.util.List;

/**
 * 商户扩展信息Mapper接口
 * 
 * @author dgtly
 * @date 2020-02-13
 */
public interface CompanyReviewedMapper
{
    /**
     * 查询商户扩展信息
     * 
     * @param id 商户扩展信息ID
     * @return 商户扩展信息
     */
    public CompanyReviewed selectCompanyReviewedById(Long id);

    /**
     * 查询商户扩展信息
     *
     * @param companyId 商户ID
     * @return 商户扩展信息
     */
    public CompanyReviewed selectCompanyReviewedByCompanyId(Long companyId);

    /**
     * 查询商户扩展信息列表
     * 
     * @param companyReviewed 商户扩展信息
     * @return 商户扩展信息集合
     */
    public List<CompanyReviewed> selectCompanyReviewedList(CompanyReviewed companyReviewed);

    /**
     * 新增商户扩展信息
     * 
     * @param companyReviewed 商户扩展信息
     * @return 结果
     */
    public int insertCompanyReviewed(CompanyReviewed companyReviewed);

    /**
     * 修改商户扩展信息
     * 
     * @param companyReviewed 商户扩展信息
     * @return 结果
     */
    public int updateCompanyReviewed(CompanyReviewed companyReviewed);

    /**
     * 删除商户扩展信息
     * 
     * @param id 商户扩展信息ID
     * @return 结果
     */
    public int deleteCompanyReviewedById(Long id);

    /**
     * 批量删除商户扩展信息
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteCompanyReviewedByIds(String[] ids);

    /**
     * @descption: 商家入驻时检测商户管理员是否在企业待审核未处理的列表中存在
     * @param:
     * @return:
     * @auther: qxp
     * @date: 2020-2-25
     */
    public int checkLoginNameUnique(String loginName);

    /**
     * @descption: 查询待审核列表，未审核排在前面
     * @param:
     * @return:
     * @auther: qxp
     * @date: 2020-2-25
     */
    List<CompanyReviewed> selectCompanyReviewedListWiteAudit(CompanyReviewed companyReviewed);

    /**
     * @descption: 查询入驻申请公示列表
     * @param:
     * @return:
     * @auther: qxp
     * @date: 2020/3/3 13:25
     */
    @SwitchEn(oldfiles = {"cr.company_name","cr.company_introduce","cr.primary_business","cr.detail_address","ce.reject_reason"},
            newfiles = {"cr.company_name_en company_name","cr.company_introduce_en company_introduce","cr.primary_business_en primary_business","cr.detail_address_en detail_address","ce.reject_reason_en reject_reason"})
    List<CompanyReviewed> selectEnterPublicityList(CompanyReviewed companyReviewed);

    /**
     * @descption: 查询商户信息变更记录
     * @param:
     * @return:
     * @auther: qxp
     * @date: 2020/3/3 13:25
     */
    List<CompanyReviewed> selectCompanyReviewedListById(CompanyReviewed cr);
}
